==> fr.opensagres.xdocreport.itext.extension-1.0.0-sources.jar: fr/opensagres/xdocreport/itext/extension/ExtendedImage.java <==
/**
 * Copyright (C) 2011-2012 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

import com.lowagie.text.Image;

public class ExtendedImage
    extends Image
{
    private float offsetY;

    public ExtendedImage( Image image, float offsetY )
    {
        super( image );
        this.offsetY = offsetY;
    }

    public ExtendedImage( Image image )
    {
        super( image );
        if ( image instanceof ExtendedImage )
        {
            ExtendedImage extImg = (ExtendedImage) image;
            this.offsetY = extImg.offsetY;
        }
    }

    public float getOffsetY()
    {
        return offsetY;
    }
}

==> fr.opensagres.xdocreport.itext.extension-1.0.4-sources.jar: fr/opensagres/xdocreport/itext/extension/ExtendedImage.java <==
/**
 * Copyright (C) 2011-2012 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

import com.lowagie.text.Image;

public class ExtendedImage
    extends Image
{
    private Image image;

    private float offsetY;

    public ExtendedImage( Image image, float offsetY )
    {
        super( image );
        this.image = Image.getInstance( image );
        this.offsetY = offsetY;
    }

    public ExtendedImage( Image image )
    {
        super( image );
        if ( image instanceof ExtendedImage )
        {
            ExtendedImage extImg = (ExtendedImage) image;
            this.image = extImg.image;
            this.offsetY = extImg.offsetY;
        }
    }

    public Image getImage()
    {
        return image;
    }

    public float getOffsetY()
    {
        return offsetY;
    }
}
